Clojure only.

cuic.browser


close!clj

(close! browser)

Closes the given browser

Closes the given browser
sourceraw docstring

launch!clj

(launch!)
(launch! opts)

Launches a Chrome browser instance by using the given options. The following options and defaults will be used:

{:headless                               true
 :window-size                            nil
 :disable-gpu                            true
 :remote-debugging-port                  0
 :disable-hang-monitor                   true
 :disable-popup-blocking                 true
 :disable-prompt-on-repost               true
 :safebrowsing-disable-auto-update       true
 :no-first-run                           true
 :disable-sync                           true
 :metrics-recording-only                 true
 :user-data-dir                          nil
 :disable-extensions                     true
 :disable-client-side-phishing-detection true
 :incognito                              false
 :disable-default-apps                   true
 :disable-background-timer-throttling    true
 :disable-background-networking          true
 :no-default-browser-check               true
 :additional-arguments                   {}
 :mute-audio                             true
 :disable-translate                      true
 :hide-scrollbars                        true}
Launches a Chrome browser instance by using the given options. The following options
   and defaults will be used:
```
{:headless                               true
 :window-size                            nil
 :disable-gpu                            true
 :remote-debugging-port                  0
 :disable-hang-monitor                   true
 :disable-popup-blocking                 true
 :disable-prompt-on-repost               true
 :safebrowsing-disable-auto-update       true
 :no-first-run                           true
 :disable-sync                           true
 :metrics-recording-only                 true
 :user-data-dir                          nil
 :disable-extensions                     true
 :disable-client-side-phishing-detection true
 :incognito                              false
 :disable-default-apps                   true
 :disable-background-timer-throttling    true
 :disable-background-networking          true
 :no-default-browser-check               true
 :additional-arguments                   {}
 :mute-audio                             true
 :disable-translate                      true
 :hide-scrollbars                        true}
```
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries