cuic.core


*browser*clj

Current browser instance that is used to perform queries and mutation. This must be set with clojure.core/binding before anything can be done.

Current browser instance that is used to perform queries
and mutation. This **must** be set with `clojure.core/binding`
before anything can be done.
sourceraw docstring

*experimental-features*clj

Experimental feature flags. Use with caution!

Experimental feature flags. Use with caution!
sourceraw docstring

*timeout*clj

Timeout in millisecond after wait stops retrying and throws a cuic.WaitTimeoutException

Timeout in millisecond after `wait` stops retrying
and throws a `cuic.WaitTimeoutException`
sourceraw docstring

*typing-speed*clj

Defines the simulated keyboard typing speed. Can be one of the predefined defaults #{:slow :normal :fast :tycitys} or custom integer indicating strokes per second (e.g. 50 = 50 strokes/sec)

Defines the simulated keyboard typing speed. Can be one of the
predefined defaults `#{:slow :normal :fast :tycitys}` or custom
integer indicating strokes per second (e.g. `50` = 50
strokes/sec)
sourceraw docstring

active?clj

(active? node)

Returns boolean whether the given node is active (focused) or not

Returns boolean whether the given node is active (focused) or not
sourceraw docstring

attrsclj

(attrs node)

Returns a map of attributes and their values for the given DOM node

Returns a map of attributes and their values for the given DOM node
sourceraw docstring

browserclj

(browser)

Returns the current browser instance.

Returns the current browser instance.
sourceraw docstring

checked?clj

(checked? node)

Returns boolean whether the given radio button / checkbox is checked or not

Returns boolean whether the given radio button / checkbox is checked or not
sourceraw docstring

classesclj

(classes node)

Returns a set of CSS classes for the given DOM node

Returns a set of CSS classes for the given DOM node
sourceraw docstring

clear-text!clj

(clear-text! input-node)

Clears all text from the given input DOM element by selecting all text and pressing backspace. If element is not active, it is activated first by clicking it.

Clears all text from the given input DOM element by selecting all
text and pressing backspace. If element is not active, it is
activated first by clicking it.
sourceraw docstring

click!clj

(click! node)

Clicks the given DOM element.

Clicks the given DOM element.
sourceraw docstring

dev-toolsclj

(dev-tools)

Escape hatch for underlying Chrome dev tools service

Escape hatch for underlying Chrome dev tools service
sourceraw docstring

disabled?clj

(disabled? node)

Returns boolean whether the given input / select / button is disabled or not

Returns boolean whether the given input / select / button is disabled or not
sourceraw docstring

documentclj

(document)

Returns the root document node or nil if document is not available

Returns the root document node or nil if document is not available
sourceraw docstring

evalclj

(eval js-code)

Evaluate JavaScript expression in the global JS context. Return value of the expression is converted into Clojure data structure. Supports async expressions (await keyword) and promises.

Evaluate JavaScript expression in the global JS context. Return value of the
expression is converted into Clojure data structure. Supports async
expressions (await keyword) and promises.
sourceraw docstring

eval-inclj

(eval-in node js-code)
source

focus!clj

(focus! node)

Focus on the given DOM element.

Focus on the given DOM element.
sourceraw docstring

goto!clj

(goto! url)

Navigates the page to the given URL.

Navigates the page to the given URL.
sourceraw docstring

has-class?clj

(has-class? node class)

Returns boolean whether the given DOM node has the given class or not

Returns boolean whether the given DOM node has the given class or not
sourceraw docstring

hover!clj

(hover! node)

Hover mouse over the given DOM element.

Hover mouse over the given DOM element.
sourceraw docstring

inner-textclj

(inner-text node)

Returns the inner text of the given DOM node

Returns the inner text of the given DOM node
sourceraw docstring

matches?clj

(matches? node selector)

Returns boolean whether the given node matches the given CSS selector or not.

Returns boolean whether the given node matches the given CSS selector or not.
sourceraw docstring

optionsclj

(options select-node)

Returns a list of options {:keys [value text selected]} for the given HTML select element.

Returns a list of options `{:keys [value text selected]}` for the given HTML
select element.
sourceraw docstring

outer-htmlclj

(outer-html node)

Returns the outer html of the given node in clojure.data.xml format (node is a map of {:keys [tag attrs content]})

Returns the outer html of the given node in clojure.data.xml format
(node is a map of {:keys [tag attrs content]})
sourceraw docstring

qclj

(q selector)
(q parent selector)

Performs a CSS query to the subtree of the given root node and returns a vector of matched nodes. If called without the root node, page document node is used as a root node for the query.

Performs a CSS query to the subtree of the given root node and returns a
vector of matched nodes. If called without the root node, page document node
is used as a root node for the query.
sourceraw docstring

rectclj

(rect node)

Returns a bounding client rect for the given node

Returns a bounding client rect for the given node
sourceraw docstring

running-tasksclj

(running-tasks)

Returns a list of currently running browser tasks. Currently only in-flight HTTP requests are supported.

Returns a list of currently running browser tasks. Currently only in-flight
HTTP requests are supported.
sourceraw docstring

screenshotclj

(screenshot node)

Takes a screen capture from the given DOM node and returns a BufferedImage instance containing the screenshot. DOM node must be visible or otherwise an exception is thrown.

If no DOM node is given, takes screenshot from the entire page.

Takes a screen capture from the given DOM node and returns a BufferedImage
instance containing the screenshot. DOM node must be visible or otherwise
an exception is thrown.

If no DOM node is given, takes screenshot from the entire page.
sourceraw docstring

scroll-to!clj

(scroll-to! node)

Scrolls window to the given DOM node if that node is not already visible in the current viewport

Scrolls window to the given DOM node if that node is not already visible
in the current viewport
sourceraw docstring

select!clj

(select! select-node & values)

Selects the given value (or values if multiselect) to the given select node

Selects the given value (or values if multiselect) to the given select node
sourceraw docstring

select-text!clj

(select-text! input-node)

Selects all text from the given input DOM element. If element is not active, it is activated first by clicking it.

Selects all text from the given input DOM element. If element is
not active, it is activated first by clicking it.
sourceraw docstring

sleepclj

(sleep ms)

Holds the execution the given milliseconds

Holds the execution the given milliseconds
sourceraw docstring

term-freqsclj

(term-freqs node)

Returns a number of occurrences per term in the given node's inner text

Returns a number of occurrences per term in the given node's inner text
sourceraw docstring

text-contentclj

(text-content node)

Returns the raw text content of the given DOM node.

Returns the raw text content of the given DOM node.
sourceraw docstring

type!clj

(type! input-node & keys)

Types text to the given input element. If element is not active, it is activated first by clicking it.

Types text to the given input element. If element is not active,
it is activated first by clicking it.
sourceraw docstring

upload!clj

(upload! input-node & files)

Sets the file(s) to the given input node. All files must instances of class java.io.File.

Sets the file(s) to the given input node. All files must instances of
class `java.io.File`.
sourceraw docstring

valueclj

(value input-node)

Returns the current value of the given input element.

Returns the current value of the given input element.
sourceraw docstring

visible?clj

(visible? node)

Returns boolean whether the given DOM node is visible in DOM or not

Returns boolean whether the given DOM node is visible in DOM or not
sourceraw docstring

waitcljmacro

(wait expr)

Evaluates the given expression and returns the value if it is truthy, otherwise pauses execution for a moment and re-tries to evaluate the expression. Continues this until thruthy value or timeout exception occurs.

Evaluates the given expression and returns the value if it is truthy,
otherwise pauses execution for a moment and re-tries to evaluate the
expression. Continues this until thruthy value or timeout exception
occurs.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries