(click! x y)Moves mouse to the given (x,y) coordinate and then clicks that position
Moves mouse to the given (x,y) coordinate and then clicks that position
(keydown! key)Triggers key-down keyboard event
Triggers key-down keyboard event
(keyup! key)Triggers key-up keyboard event
Triggers key-up keyboard event
(move-mouse! x y)Moves mouse to the given (x,y) coordinate
Moves mouse to the given (x,y) coordinate
(type! & keys)Types the given keys and text with the keyboard
Types the given keys and text with the keyboard
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |