cuic.repl


default-launch-optsclj

source

disable-cache!clj

(disable-cache! browser)

Disables cache from the given browser instance

Disables cache from the given browser instance
sourceraw docstring

inspectclj

(inspect nodes)

Logs the given DOM nodes to then opened browser's console

Logs the given DOM nodes to then opened browser's console
sourceraw docstring

launch-dev-browser!clj

(launch-dev-browser!)
(launch-dev-browser! opts)

Launches a new (visible) browser and sets it to the default browser.

Launches a new (visible) browser and sets it to the default browser.
sourceraw docstring

set-browser!clj

(set-browser! browser)

Forcefully sets the default browser to the given one so that every core function is run against this browser.

Forcefully sets the default browser to the given one so that every core
function is run against this browser.
sourceraw docstring

set-timeout!clj

(set-timeout! new-timeout)

Sets the new default wait timeout for REPL

Sets the new default wait timeout for REPL
sourceraw docstring

set-typing-speed!clj

(set-typing-speed! new-speed)

Sets the new default typing speed for REPL

Sets the new default typing speed for REPL
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries