cuic.util


at-most-oneclj

(at-most-one nodes)

Checks that the given node or vector of nodes contains one valid DOM node and returns it. If there is no valid DOM nodes, then returns nil. Otherwise throws an exception.

Checks that the given node or vector of nodes contains one valid DOM node
and returns it. If there is no valid DOM nodes, then returns `nil`.
Otherwise throws an exception.
sourceraw docstring

mutationcljmacro

(mutation & body)

Helper macro to run custom mutation requiring direct DevTools access (see cuic.core/dev-tools). Usually you shouldn't need this if you're using and mutations from cuic.core.

To see usage, take a look at e.g. cuic.core/focus! implementation.

Helper macro to run custom mutation requiring direct DevTools access 
(see `cuic.core/dev-tools`). Usually you shouldn't need this if you're
using and mutations from `cuic.core`.

To see usage, take a look at e.g. `cuic.core/focus!` implementation.
sourceraw docstring

oneclj

(one nodes)

Checks that the given node or vector of nodes contains exactly one valid DOM node and returns it. Otherwise throws an exception.

Checks that the given node or vector of nodes contains exactly one
valid DOM node and returns it. Otherwise throws an exception.
sourceraw docstring

one-visibleclj

(one-visible node)

Checks that the given node or vector of nodes contains exactly one valid DOM node and returns it. Otherwise throws an exception. Also requires that the node is visible and throws an exception if this requirement is not fulfilled.

Checks that the given node or vector of nodes contains exactly one
valid DOM node and returns it. Otherwise throws an exception. Also requires
that the node is visible and throws an exception if this requirement is
not fulfilled.
sourceraw docstring

runcljmacro

(run & body)

Helper macro to run custom queries requiring direct DevTools access (see cuic.core/dev-tools). Usually you shouldn't need this if you're using and combining functions from cuic.core.

To see usage, take a look at e.g. cuic.core/options implementation.

Helper macro to run custom queries requiring direct DevTools access 
(see `cuic.core/dev-tools`). Usually you shouldn't need this if you're
using and combining functions from `cuic.core`.

To see usage, take a look at e.g. `cuic.core/options` implementation.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries