(disable-cache! browser)Disables cache from the given browser instance
Disables cache from the given browser instance
(inspect nodes)Logs the given DOM nodes to then opened browser's console
Logs the given DOM nodes to then opened browser's console
(launch-dev-browser!)(launch-dev-browser! opts)Launches a new (visible) browser and sets it to the default browser.
Launches a new (visible) browser and sets it to the default browser.
(set-browser! browser)Forcefully sets the default browser to the given one so that every core function is run against this browser.
Forcefully sets the default browser to the given one so that every core function is run against this browser.
(set-timeout! new-timeout)Sets the new default wait timeout for REPL
Sets the new default wait timeout for REPL
(set-typing-speed! new-speed)Sets the new default typing speed for REPL
Sets the new default typing speed for REPL
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |